@@ -40,7 +40,7 @@ from eos_downloader import (
     MSG_TOKEN_EXPIRED,
 )
 from eos_downloader.data import DATA_MAPPING
-from eos_downloader.download import DownloadProgressBar
+from eos_downloader.download import DownloadProgressBar, REQUEST_HEADERS
 
 # logger = logging.getLogger(__name__)
 
@@ -263,7 +263,10 @@ class ObjectDownloader:
             self.authenticate()
         jsonpost = {"sessionCode": self.session_id}
         result = requests.post(
-            ARISTA_SOFTWARE_FOLDER_TREE, data=json.dumps(jsonpost), timeout=self.timeout
+            ARISTA_SOFTWARE_FOLDER_TREE,
+            data=json.dumps(jsonpost),
+            timeout=self.timeout,
+            headers=REQUEST_HEADERS,
         )
         try:
             folder_tree = result.json()["data"]["xml"]
@@ -332,7 +335,10 @@ class ObjectDownloader:
             self.authenticate()
         jsonpost = {"sessionCode": self.session_id, "filePath": remote_file_path}
         result = requests.post(
-            ARISTA_DOWNLOAD_URL, data=json.dumps(jsonpost), timeout=self.timeout
+            ARISTA_DOWNLOAD_URL,
+            data=json.dumps(jsonpost),
+            timeout=self.timeout,
+            headers=REQUEST_HEADERS,
         )
         if "data" in result.json() and "url" in result.json()["data"]:
             # logger.debug('URL to download file is: {}', result.json())
@@ -421,7 +427,10 @@ class ObjectDownloader:
         jsonpost = {"accessToken": credentials}
 
         result = requests.post(
-            session_code_url, data=json.dumps(jsonpost), timeout=self.timeout
+            session_code_url,
+            data=json.dumps(jsonpost),
+            timeout=self.timeout,
+            headers=REQUEST_HEADERS,
         )
 
         if result.json()["status"]["message"] in [
@@ -485,12 +494,12 @@ class ObjectDownloader:
                 hash_result = self._compute_hash_sh512sum(
                     file=file_downloaded, hash_expected=hash_expected
                 )
-        if not hash_result:
-            logger.error("Downloaded file is corrupted, please check your connection")
-            console.print(
-                "❌  Downloaded file is corrupted, please check your connection"
-            )
-            return False
+            if not hash_result:
+                logger.error("Downloaded file is corrupted, please check your connection")
+                console.print(
+                    "❌  Downloaded file is corrupted, please check your connection"
+                )
+                return False
         logger.info("Downloaded file is correct.")
         console.print("✅  Downloaded file is correct.")
         return True
@@ -547,7 +556,9 @@ class ObjectDownloader:
         if noztp:
             self._disable_ztp(file_path=file_path)
 
-    def docker_import(self, image_name: str = "arista/ceos") -> None:
+    def docker_import(
+        self, image_name: str = "arista/ceos", is_latest: bool = False
+    ) -> None:
         """
         Import docker container to your docker server.
 
@@ -561,6 +572,9 @@ class ObjectDownloader:
         logger.info(f"Importing image {self.filename} to {docker_image}")
         console.print(f"🚀 Importing image {self.filename} to {docker_image}")
         os.system(f"$(which docker) import {self.filename} {docker_image}")
+        if is_latest:
+            console.print(f"🚀 Configuring {docker_image}:{self.version} to be latest")
+            os.system(f"$(which docker) tag {docker_image} {image_name}:latest")
         for filename in glob.glob(f"{self.filename}*"):
             try:
                 os.remove(filename)
